# Pygame_spiel: Pygame-based UI to play board Reinforcement Learning games from OpenSpiel
PygameSpiel is a [Pygame](https://www.pygame.org)-based library to play board games from the library [OpenSpiel](https://github.com/google-deepmind/open_spiel) against AI algorithms.

## Install
```bash
pip install pygame_spiel
```

## Version 0.1.0
Games currently available: 
* Breakthrough
* Tic Tac Toe

AI algorithms available:
* mcts, DQN (currently only for breakthrough)

**more to come...**

## Overview
Run Pygame_spiel with:

```bash
pygame_spiel
```

![menu](https://github.com/giogix2/pygame_spiel/assets/5859539/10f4f6ba-7d96-4586-8966-e52050a16343)

Use your mouse to select the cell (tic tac toe) or select pawn and destination cell (breakthrough).

![breakthrough_tic_tac_toe](https://github.com/giogix2/pygame_spiel/assets/5859539/3c084532-b910-429f-ac98-9b8d4c196299)
